# 🔦 Bookshelf Raycast

This datapack allows you to cast rays and check for collisions with blocks or entities.

> “Reality only reveals itself when it is illuminated by a ray of poetry.”
>
> -- Georges Braque

For more details and usage examples, check out the Bookshelf [documentation](https://docs.mcbookshelf.dev/en/latest/modules/raycast.html).


## 📖 About Bookshelf

This module is part of the [Bookshelf Library](https://docs.mcbookshelf.dev/en/latest/index.html), a modular library datapack designed to simplify complex systems in Minecraft. Explore the full range of modules and discover how Bookshelf can simplify your Minecraft creations!
